jQuery(document).ready(function ($) {
  $('#seo-rewriter-title').click(function (e) {
    const titlePromptText = $('#seo-rewriter-title-prompts').find(":selected").text();
    e.preventDefault();
    rewrite('title', titlePromptText);
  });
  
  $('#seo-rewriter-content').click(function () {
    const contentPromptText = $('#seo-rewriter-content-prompts').find(":selected").text();
    rewrite('content', contentPromptText);
  });

  // This function wraps $.ajax in a Promise
  function postData(url = '', data = {}) {
    return new Promise((resolve, reject) => {
      $.ajax({
        type: 'POST',
        url: url,
        data: data,
        success: function(data) {
          resolve(data);
        },
        error: function(error) {
          reject(error);
        }
      });
    });
  }

 
  async function rewrite(type, promptText) {
    jQuery('.edit-post-layout').append('<div style="position:absolute; z-index:9999;" id="loader" class="loader-background"><img src="/wp-content/plugins/opengraphy-chatgpt/includes/assets/logo/logo-og.png" alt="Logo OpenGraphy" class="loader-logo"> <div class="loader-animation"></div></div>');
    showLoader();
    if(type === 'content') {
      let blocks = jQuery('.wp-block-paragraph');
      blocks = blocks.add(jQuery('.wp-block-heading'));
      blocks = blocks.add(jQuery('.wp-block-list-item .rich-text'));
      const count = blocks.length;
      for(let index = 0; index < count; index++) {
        const block = $(blocks[index]);
        const blockContent = block.html();
        if(blockContent === '') {
          continue;
        }
        const data = {
          action: 'seo_rewriter_rewrite',
          security: seo_rewriter.nonce,
          post_id: $('#post_ID').val(),
          promptText: promptText + ' and do not remove html styles: ' + blockContent,
          type: type,
        };
        const response = await postData(seo_rewriter.ajax_url, data);

        if (response.success) {
            if ($('#post_type').val() === 'product') {
              if (typeof tinyMCE !== 'undefined' && tinyMCE.get('content')) {
                tinyMCE.get('content').setContent(response.data.generated_text);
              } else {
                // Fallback if TinyMCE is not active
                $('#tinymce').html(response.data.generated_text);
              }
            } else {
              // Update the regular content
              if (typeof tinyMCE !== 'undefined' && tinyMCE.activeEditor) {
                tinyMCE.activeEditor.setContent(response.data.generated_text);
              } else {
                block.html(response.data.generated_text);
                block.focus();
                // $('.block-editor-rich-text__editable').text(response.data.generated_text);
              }
            }
          // }
        } else {
          alert('An error occurred while rewriting the ' + type + '.');
        }
        if(index === count - 1) {
          hideLoader();
        }
      };
    } else {
      const data = {
        action: 'seo_rewriter_rewrite',
        security: seo_rewriter.nonce,
        post_id: $('#post_ID').val(),
        promptText: promptText,
        type: type,
      };
      $.post(seo_rewriter.ajax_url, data, function (response) {
        hideLoader();
        if (response.success) {
          // if (type === 'title') {
          if ($('#post_type').val() === 'product') {
            $('input[name="post_title"]').val(response.data.generated_text);
          } else {
            $('.editor-post-title__input').html(response.data.generated_text);
          }
        } else {
          alert('An error occurred while rewriting the ' + type + '.');
        }
      });
    }
  }
});
