<?php
require 'vendor/autoload.php';

use GuzzleHttp\Client;

// TODO declare $advancedSettings as global

if(!function_exists('openai_rewrite')) {
  function openai_rewrite($text,  $api_key, $promptText = '') {
    if (!empty($promptText)) {
      $text = $promptText . ' ' . $text;
    }

    if(is_subscription_active()) {
      $model = get_option('seo_rewriter_model') ?? 'gpt-3.5-turbo-0301';
      $creativity_level = get_option('seo_rewriter_creativity_level') ?? 0.5;
      $title_length = get_option('seo_rewriter_title_length') ?? 5;
      $content_length = get_option('seo_rewriter_content_length') ?? 1500;
      $seo_rewriter_keywords = get_option('seo_rewriter_keywords');
      $seo_rewriter_tone = get_option('seo_rewriter_tone') ?? 'formal';
    } else {
      // Free version
      $model = 'gpt-3.5-turbo-0301';
      $creativity_level = 0.5;
      $title_length = 5;
      $content_length = 1500;
      $seo_rewriter_keywords = '';
      $seo_rewriter_tone = 'formal';
    }

    // Set the default value for $max_tokens
    $default_max_tokens = 1500; // Set the desired default value here
    // Set default max tokens value if user doesn't set it
    if (empty($max_tokens)) {
      $max_tokens = $default_max_tokens;
    } else {
      $max_tokens = $title_length + $content_length;
    }

    // Add to prompt
    // $seo_rewriter_keywords = $advancedSettings['seo_rewriter_keywords'];
    // $seo_rewriter_tone = $advancedSettings['seo_rewriter_tone'];

    try {
      $client = new Client();  
      $response = $client->post('https://api.openai.com/v1/chat/completions', [
        'headers' => [
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $api_key,
        ],
        'json' => [
          'model'=> $model,
          'messages' => [
            [
              'role' => 'system', 'content' => 'You are a SEO copywriter writing engaging content on WordPress that I use to market my activities on my blog',
              'role' => 'user', 'content' => $text
            ]
          ],
          'max_tokens' => $max_tokens,
          'n' => 1,
          'stop' => null,
          'temperature' => (float)$creativity_level,
        ]
      ]);
      $data = json_decode($response->getBody(), true);

      $clean_response = ltrim($data['choices'][0]['message']['content'], "/\n+/");
      $clean_response = stripslashes(trim($clean_response, '"'));
      return [
        'generated_text' => $clean_response,
        'n_generated_tokens_total' => $data['usage']['total_tokens']
       ];

    } catch (Exception $e) {
        return $e->getMessage();
        header('HTTP/1.0 401 Unauthorized');
        return $e->getMessage();
    }
  }
}

if(!function_exists('openai_usage')) {
  function openai_usage() {
    try {
      // Set your API credentials
      $openai_api_key = decrypt_api_key(get_option('seo_rewriter_openai_api_key'));

      // Set the API endpoint URL
      $url = 'https://api.openai.com/v1/usage';

      // Create a new GuzzleHttp client instance
      $client = new Client();
      // Set the date query parameter in the format of YYYY-MM-DD
      $date = date('Y-m-d');

      // Send an HTTP GET request to the API endpoint with your API key
      $response = $client->request('GET', $url, [
        'headers' => [
          'Authorization' => 'Bearer ' . $openai_api_key,
          'Content-Type' => 'application/json',
        ],
        'query' => [
          'date' => $date,
        ],
      ]);

      // Decode the JSON response
      $usage = json_decode($response->getBody(), true);
      return $usage;
    } catch (Exception $e) {
      header('HTTP/1.0 401 Unauthorized');
      return $e->getMessage();
    }
    
  }
}