<?php
/*
 * Plugin Name:       OpenGraphy ChatGPT
 * Plugin URI:        https://chatgpt-wordpress.opengraphy.com/
 * Description:       Create and rewrite content with ChatGPT and OpenAI APIs
 * Version:           1.1.4
 * Requires at least: 5.1.15
 * Requires PHP:      7.3.33
 * Author:            Antoine GOUNEL antoine.gounel@opengraphy.com
 * Author URI:        https://profiles.wordpress.org/antoinegounel/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Update URI:        https://chatgpt-wordpress.opengraphy.com/
 * Text Domain:       opengraphy-chatgpt
 * Domain Path:       
 */

require_once( plugin_dir_path( __FILE__ ) . 'vendor/autoload.php');
require_once( plugin_dir_path( __FILE__ ) . 'functions.php');
require_once( plugin_dir_path( __FILE__ ) . 'rewriter/functions.php');
require_once( plugin_dir_path( __FILE__ ) . 'blocks/loader.php');
require_once( plugin_dir_path( __FILE__ ) . 'generator/ajax-generator.php');

// Ajax
require_once( plugin_dir_path( __FILE__ ) . 'settings/ajax-settings.php');
require_once( plugin_dir_path( __FILE__ ) . 'rewriter/ajax-rewrite.php');

if (file_exists(plugin_dir_path(__FILE__) . '.env')) {
  $dotenv = Dotenv\Dotenv::createImmutable(plugin_dir_path(__FILE__));
  $dotenv->load();
}

if($_SERVER['HTTP_HOST'] !== 'chatgpt-wordpress.opengraphy.com') {
  define('__API_URL__', 'https://chatgpt-wordpress.opengraphy.com');
} else {
  define('__API_URL__', $_ENV['API_URL']);
}

require 'openai-api.php';
require 'functions.php';

function hide_wordpress_notice() {
  $screen = get_current_screen();
  if ( isset($_GET['page']) && 
    ($_GET['page'] == 'SEO Rewriter' 
    || $_GET['page'] == 'seo_rewriter_api_settings' 
    || $_GET['page'] == 'seo_rewriter_advanced_settings'
    || $_GET['page'] == 'seo_rewriter_activate'
    || $_GET['page'] == 'seo_rewriter_prompt_settings'
    || $_GET['page'] == 'seo-rewriter-submenu-page'
    || $_GET['page'] == 'seo_rewritter_generate_content')
    ) {
    remove_all_actions('admin_notices');
    add_filter(
      'admin_footer_text',
      function ( $footer_text ) {
          // Edit the line below to customize the footer text.
          $footer_text = '&copy; 2023 ChatGPT for WordPress. All rights reserved.';
           
          return $footer_text;
      }
    );
    function remove_version_footer() {
      remove_filter( 'update_footer', 'core_update_footer' ); 
    }
    add_action( 'admin_menu', 'remove_version_footer' );
  }
}
add_action('admin_head', 'hide_wordpress_notice');

// This function will display the plugin directly on the dashoard
function seo_rewritter_plugin_add_menu_page() {
    add_menu_page(
      'ChatGPT for WordPress',
      'ChatGPT for WordPress',
      'manage_options',
      'SEO Rewriter',
      'seo_rewriter_settings_page',
      'dashicons-format-chat',
      3,
    );
    add_submenu_page(
      'SEO Rewriter',
      'Generate New',
      'Generate New',
      'manage_options',
      'seo_rewritter_generate_content',
      'seo_rewritter_generate_content'
    );
	add_submenu_page(
      'SEO Rewriter',
      'Rewrite Prompts',
      'Rewrite Prompts',
      'manage_options',
      'seo_rewriter_prompt_settings',
      'seo_rewriter_prompt_settings'
    );
	    add_submenu_page(
      'SEO Rewriter',
      'Advanced Settings',
      'Advanced Settings',
      'manage_options',
      'seo_rewriter_advanced_settings',
      'seo_rewriter_advanced_settings'
    );
    add_submenu_page(
      'SEO Rewriter',
      'OpenAI API Key',
      'OpenAI API Key',
      'manage_options',
      'seo_rewriter_api_settings',
      'seo_rewriter_api_settings'
    );
    add_submenu_page(
      'SEO Rewriter',
      'Licence key',
      'Licence key',
      'manage_options',
      'seo_rewriter_activate',
      'seo_rewriter_activate'
  );
   
}
add_action( 'admin_menu', 'seo_rewritter_plugin_add_menu_page');


function seo_rewriter_api_settings() {
  require_once( plugin_dir_path( __FILE__ ) . 'settings/api-settings.php' );
}

function seo_rewriter_prompt_settings() {
	  // Get the number of published posts
  $count_posts = wp_count_posts('post')->publish;

  // Get the number of published pages
  $count_pages = wp_count_posts('page')->publish;
  require_once( plugin_dir_path( __FILE__ ) . 'settings/prompt-settings.php' );
}

function seo_rewriter_advanced_settings() {
  require_once( plugin_dir_path( __FILE__ ) . 'settings/advanced-settings.php' );
}

function seo_rewritter_generate_content (){
  require_once( plugin_dir_path( __FILE__ ) . 'generator/generator-content.php' );
}

function seo_rewriter_activate() {
  require_once( plugin_dir_path( __FILE__ ) . 'settings/seo-rewriter-activate.php' );
}

function seo_rewriter_welcome_message() {
  require_once(plugin_dir_path( __FILE__) . 'blocks/welcome-page.php');
}

add_action('admin_enqueue_scripts', 'seo_rewriter_enqueue_scripts');
add_action('save_post', 'seo_rewriter_save_post_data', 10, 2);

// Implement the 'seo_rewriter_enqueue_scripts' function to load the necessary JavaScript and CSS files in the admin area.
function seo_rewriter_enqueue_scripts($hook) {
  // Scripts
  wp_enqueue_script('seo-settings-js', plugin_dir_url(__FILE__) . 'includes/js/seo-settings.js', array('jquery'), '1.0', true);
  wp_enqueue_script('seo-rewriter-js', plugin_dir_url(__FILE__) . 'includes/js/seo-rewriter.js', array('jquery'), '1.0', true);
  wp_enqueue_script('loader-js', plugin_dir_url(__FILE__) . 'includes/js/loader.js', array('jquery'), '1.0', true);
  wp_enqueue_script('generator-js', plugin_dir_url(__FILE__) . 'includes/js/generator.js?v=1.01', array('jquery'), '1.0', true);
  // Styles
  wp_enqueue_style('seo-rewriter-style', plugins_url('includes/css/seo-rewriter.css', __FILE__), [], '1.0');
  wp_enqueue_style('loader-css', plugins_url('includes/css/loader.css', __FILE__), [], '1.0');
  wp_enqueue_style('loader-css', plugins_url('includes/css/generator.css', __FILE__), [], '1.0');

  // Define the admin-ajax.php URL and pass it to the script
  $ajax_url = admin_url( 'admin-ajax.php' );
  wp_localize_script('seo-rewriter-js', 'seo_rewriter', [
    'ajax_url' => admin_url('admin-ajax.php'),
    'nonce' => wp_create_nonce('seo_rewriter_nonce'),
    'prompts' => get_option('seo_rewriter_prompts'),
    'current_language' => get_locale()
  ]);
}
add_action('admin_enqueue_scripts', 'seo_rewriter_enqueue_scripts', 10, 1);

// Implement the 'seo_rewriter_save_post_data' function to save post data when the post is updated
function seo_rewriter_save_post_data($post_id, $post) {
  if (!isset($_POST['seo_rewriter_nonce_field']) || !wp_verify_nonce($_POST['seo_rewriter_nonce_field'], 'seo_rewriter_nonce')) {
    return;
  }

  if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
    return;
  }

  if (!current_user_can('edit_post', $post_id)) {
    return;
  }
}

// Register AJAX actions
add_action('wp_ajax_seo_rewriter_load_prompts', 'seo_rewriter_load_prompts');
function seo_rewriter_load_prompts() {
  $title_prompts = get_option('seo_rewriter_title_prompts', array());
  $content_prompts = get_option('seo_rewriter_content_prompts', array());
  
  wp_send_json_success(array(
    'title_prompts' => $title_prompts,
    'title_prompts_options' => $title_prompts_options,
    'content_prompts' => $content_prompts,
    'content_prompts_options' => $content_prompts_options,
  ));
}

define('__CACHE_FILE__', 'api-response.txt');
function check_license_key($regenerate_cache = false) {
  $license_key = get_option('chat_gpt_license_key');

  // Obtenir le chemin du répertoire de téléchargement de WordPress
  $upload_dir = wp_upload_dir();
  $cache_file = $upload_dir['basedir'] . '/' . $encryptedName = encryptFileName(__CACHE_FILE__);;

  if(empty($license_key)) {
    return false;
  }

  $status = 'not-active';
  // Vérifiez si la réponse de l'API est en cache
  if (!$regenerate_cache && file_exists($cache_file) && (time() - filemtime($cache_file) < 3600)) {
    $status = base64_decode(file_get_contents($cache_file));
    file_put_contents($cache_file, base64_encode($status));
  } else {
    $api_url = __API_URL__ . '/wp-json/api/v1/check-subscription/' . urlencode($license_key);
    $options = array(
      'http' => array(
          'method' => 'GET',
          'header' => 'Content-type: application/json\r\n'
      )
    );
    $context = stream_context_create($options);
    $response = file_get_contents($api_url, false, $context);
    if($response) {
      $api_result = json_decode($response);
      if($api_result->status == 'active') {
        $status = 'active';
      } else {
        $status = 'not-active';
      }
    }
    file_put_contents($cache_file, base64_encode($status));
  }
  
}

// Enregistrer une fonction cron pour vérifier la clé de licence toutes les heures
add_action('wp', 'register_license_check_cron');
function register_license_check_cron() {
  if (!wp_next_scheduled('license_check_cron')) {
    wp_schedule_event(time(), 'hourly', 'license_check_cron');
  }
}

function encryptFileName($fileName) {
  $uniqueID = $_SERVER['HTTP_HOST'];
  $encryptedName = md5($fileName . $uniqueID); // use MD5 hash algorithm to encrypt the file name
  return $encryptedName;
}

function is_subscription_active() {
  $upload_dir = wp_upload_dir();
  $encryptedName = encryptFileName(__CACHE_FILE__);
  $cache_file = $upload_dir['basedir'] . '/' . $encryptedName;
  if (!file_exists($cache_file)) {
      return false;
  }
  $cache_data = file_get_contents($cache_file);
  $cache_data = base64_decode($cache_data); // assuming the cache data is serialized
  // Check if the subscription is active
  if (isset($cache_data) && $cache_data === 'active') {
      return true;
  } else {
      return false;
  }
}

function my_plugin_activation_function() {
  $titlePrompts = get_option('seo_rewriter_title_prompts');
  $contentPrompts = get_option( 'seo_rewriter_content_prompts');

  if(!empty($contentPrompts) || !empty($titlePrompts)) {
    return;
  }
  $prompts = [
    0 => 'Fix syntax and grammar',
    1 => 'Make it more professional',
    2 => 'Make it longer, add paragraphs',
    3 => 'Rewrite as an SEO expert',
    4 => 'Translate into English'
  ];
  update_option( 'seo_rewriter_title_prompts', $prompts );
  update_option( 'seo_rewriter_content_prompts', $prompts );
}
register_activation_hook( __FILE__, 'my_plugin_activation_function' );